@@ -17,12 +17,17 @@ use XML::Feed;
 
 use Perlanet::Types;
 
-our $VERSION = '2.0.8';
+our $VERSION = '2.0.9';
 
 with 'MooseX::Traits';
 
 $XML::Atom::ForceUnicode = 1;
 
+has 'config' => (
+  is => 'ro',
+  isa => 'HashRef',
+);
+
 has 'ua' => (
   is         => 'rw',
   isa        => 'LWP::UserAgent',
@@ -139,6 +144,11 @@ See L</ATTRIBUTES> below for details of the key/value pairs to pass in.
 
 =over
 
+=item config
+
+A hash reference that contains the complete contents of the configuration
+file.
+
 =item ua
 
 An instance of L<LWP::UserAgent>. Defaults to a simple agent using C<<
