@@ -3,9 +3,6 @@ package Perlanet::Trait::FeedFile;
 use strict;
 use warnings;
 
-use 5.6.0;
-our $VERSION = '0.58';
-
 use Moose::Role;
 use namespace::autoclean;
 
@@ -45,12 +42,13 @@ has 'feed' => (
   isa       => 'HashRef',
   is        => 'rw',
   default   => sub {
-    { file => 'atom.xml', format => 'Atom' }
+    { file => 'atom.xml', format => 'Atom' };
   },
 );
 
 after 'render' => sub {
-  my ($self, $feed) = @_;
+  my $self = shift;
+  my ($feed) = @_;
   return unless $self->feed->{file};
 
   open my $feedfile, '>', $self->feed->{file}
